Index: src/wp-admin/js/comment.js
===================================================================
--- src/wp-admin/js/comment.js	(revision 39923)
+++ src/wp-admin/js/comment.js	(working copy)
@@ -34,7 +34,8 @@
 
 	$timestampdiv.find('.save-timestamp').click( function( event ) { // crazyhorse - multiple ok cancels
 		var aa = $('#aa').val(), mm = $('#mm').val(), jj = $('#jj').val(), hh = $('#hh').val(), mn = $('#mn').val(),
-			newD = new Date( aa, mm - 1, jj, hh, mn );
+			newD = new Date( aa, mm - 1, jj, hh, mn ),
+			commentTime;
 
 		event.preventDefault();
 
@@ -45,6 +46,10 @@
 			$timestampwrap.removeClass( 'form-invalid' );
 		}
 
+		commentTime = commentL10n.timeFormat
+			.replace( '%1$s', ( '00' + hh ).slice( -2 ) )
+			.replace( '%2$s', ( '00' + mn ).slice( -2 ) );
+
 		$timestamp.html(
 			commentL10n.submittedOn + ' <b>' +
 			commentL10n.dateFormat
@@ -51,8 +56,7 @@
 				.replace( '%1$s', $( 'option[value="' + mm + '"]', '#mm' ).attr( 'data-text' ) )
 				.replace( '%2$s', parseInt( jj, 10 ) )
 				.replace( '%3$s', aa )
-				.replace( '%4$s', ( '00' + hh ).slice( -2 ) )
-				.replace( '%5$s', ( '00' + mn ).slice( -2 ) ) +
+				.replace( '%4$s', commentTime ) +
 				'</b> '
 		);
 
Index: src/wp-admin/js/post.js
===================================================================
--- src/wp-admin/js/post.js	(revision 39923)
+++ src/wp-admin/js/post.js	(working copy)
@@ -720,7 +720,8 @@
 
 			var attemptedDate, originalDate, currentDate, publishOn, postStatus = $('#post_status'),
 				optPublish = $('option[value="publish"]', postStatus), aa = $('#aa').val(),
-				mm = $('#mm').val(), jj = $('#jj').val(), hh = $('#hh').val(), mn = $('#mn').val();
+				mm = $('#mm').val(), jj = $('#jj').val(), hh = $('#hh').val(), mn = $('#mn').val(),
+				publishTime;
 
 			attemptedDate = new Date( aa, mm - 1, jj, hh, mn );
 			originalDate = new Date( $('#hidden_aa').val(), $('#hidden_mm').val() -1, $('#hidden_jj').val(), $('#hidden_hh').val(), $('#hidden_mn').val() );
@@ -751,6 +752,10 @@
 				// Re-set to the current value.
 				$('#timestamp').html(stamp);
 			} else {
+				publishTime = postL10n.timeFormat
+						.replace( '%1$s', ( '00' + hh ).slice( -2 ) )
+						.replace( '%2$s', ( '00' + mn ).slice( -2 ) );
+
 				$('#timestamp').html(
 					'\n' + publishOn + ' <b>' +
 					postL10n.dateFormat
@@ -757,8 +762,7 @@
 						.replace( '%1$s', $( 'option[value="' + mm + '"]', '#mm' ).attr( 'data-text' ) )
 						.replace( '%2$s', parseInt( jj, 10 ) )
 						.replace( '%3$s', aa )
-						.replace( '%4$s', ( '00' + hh ).slice( -2 ) )
-						.replace( '%5$s', ( '00' + mn ).slice( -2 ) ) +
+						.replace( '%4$s', publishTime ) +
 						'</b> '
 				);
 			}
Index: src/wp-admin/includes/template.php
===================================================================
--- src/wp-admin/includes/template.php	(revision 39923)
+++ src/wp-admin/includes/template.php	(working copy)
@@ -725,10 +725,12 @@
 	$year = '<label><span class="screen-reader-text">' . __( 'Year' ) . '</span><input type="text" ' . ( $multi ? '' : 'id="aa" ' ) . 'name="aa" value="' . $aa . '" size="4" maxlength="4"' . $tab_index_attribute . ' autocomplete="off" /></label>';
 	$hour = '<label><span class="screen-reader-text">' . __( 'Hour' ) . '</span><input type="text" ' . ( $multi ? '' : 'id="hh" ' ) . 'name="hh" value="' . $hh . '" size="2" maxlength="2"' . $tab_index_attribute . ' autocomplete="off" /></label>';
 	$minute = '<label><span class="screen-reader-text">' . __( 'Minute' ) . '</span><input type="text" ' . ( $multi ? '' : 'id="mn" ' ) . 'name="mn" value="' . $mn . '" size="2" maxlength="2"' . $tab_index_attribute . ' autocomplete="off" /></label>';
+	/* translators: 1: hour, 2: minute */
+	$time = '<span dir="ltr">' . sprintf( __( '%1$s:%2$s' ), $hour, $minute ) . '</span>';
 
 	echo '<div class="timestamp-wrap">';
-	/* translators: 1: month, 2: day, 3: year, 4: hour, 5: minute */
-	printf( __( '%1$s %2$s, %3$s @ %4$s:%5$s' ), $month, $day, $year, $hour, $minute );
+	/* translators: 1: month, 2: day, 3: year, 4: time */
+	printf( __( '%1$s %2$s, %3$s @ %4$s' ), $month, $day, $year, $time );
 
 	echo '</div><input type="hidden" id="ss" name="ss" value="' . $ss . '" />';
 
Index: src/wp-includes/script-loader.php
===================================================================
--- src/wp-includes/script-loader.php	(revision 39923)
+++ src/wp-includes/script-loader.php	(working copy)
@@ -556,8 +556,10 @@
 			'publishOn' => __('Publish on:'),
 			'publishOnFuture' =>  __('Schedule for:'),
 			'publishOnPast' => __('Published on:'),
-			/* translators: 1: month, 2: day, 3: year, 4: hour, 5: minute */
-			'dateFormat' => __('%1$s %2$s, %3$s @ %4$s:%5$s'),
+			/* translators: 1: month, 2: day, 3: year, 4: time */
+			'dateFormat' => __( '%1$s %2$s, %3$s @ %4$s' ),
+			/* translators: 1: hour, 2: minute */
+			'timeFormat' => __( '%1$s:%2$s' ),
 			'showcomm' => __('Show more comments'),
 			'endcomm' => __('No more comments found.'),
 			'publish' => __('Publish'),
@@ -595,8 +597,10 @@
 		$scripts->add_data( 'comment', 'group', 1 );
 		did_action( 'init' ) && $scripts->localize( 'comment', 'commentL10n', array(
 			'submittedOn' => __( 'Submitted on:' ),
-			/* translators: 1: month, 2: day, 3: year, 4: hour, 5: minute */
-			'dateFormat' => __( '%1$s %2$s, %3$s @ %4$s:%5$s' )
+			/* translators: 1: month, 2: day, 3: year, 4: time */
+			'dateFormat' => __( '%1$s %2$s, %3$s @ %4$s' ),
+			/* translators: 1: hour, 2: minute */
+			'timeFormat' => __( '%1$s:%2$s' ),
 		) );
 
 		$scripts->add( 'admin-gallery', "/wp-admin/js/gallery$suffix.js", array( 'jquery-ui-sortable' ) );
